@@ -4,7 +4,7 @@ use Digest::MD5 'md5';
 use Carp;
 use strict;
 use vars qw($VERSION);
-$VERSION = '2.10';
+$VERSION = '2.11';
 
 sub new {
     my $class = shift;
@@ -210,7 +210,7 @@ sub crypt (\$$){
 sub finish (\$) {
     my $self = shift;
     my $bs    = $self->{'blocksize'};
-    my $block = $self->{'buffer'} || '';
+    my $block = length $self->{'buffer'} ? $self->{'buffer'} : '';
 
     $self->{civ} ||= '';
 
@@ -236,7 +236,7 @@ sub finish (\$) {
 
 sub _standard_padding ($$$) {
   my ($b,$bs,$decrypt) = @_;
-  $b ||= '';
+  $b = length $b ? $b : '';
   if ($decrypt eq 'd') {
      substr($b, -unpack("C",substr($b,-1)))='';
      return $b;
@@ -248,7 +248,7 @@ sub _standard_padding ($$$) {
 sub _space_padding ($$$) {
   my ($b,$bs,$decrypt) = @_;
   return unless length $b;
-  $b ||= '';
+  $b = length $b ? $b : '';
   if ($decrypt eq 'd') {
      $b=~ s/ *$//s;
      return $b;
@@ -259,7 +259,7 @@ sub _space_padding ($$$) {
 sub _null_padding ($$$) {
   my ($b,$bs,$decrypt) = @_;
   return unless length $b;
-  $b ||= '';
+  $b = length $b ? $b : '';
   if ($decrypt eq 'd') {
      $b=~ s/\0*$//s;
      return $b;
@@ -270,7 +270,7 @@ sub _null_padding ($$$) {
 sub _oneandzeroes_padding ($$$) {
   my ($b,$bs,$decrypt) = @_;
   return unless length $b;
-  $b ||= '';
+  $b = length $b ? $b : '';
   if ($decrypt eq 'd') {
      my $hex = unpack("H*", $b);
      $hex =~ s/80*$//s;
